==> qtjambi-qt3drender-6.6.0-sources.jar: io/qt/qt3d/render/PropertyReaderInterface.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>Qt3DRender::PropertyReaderInterface</code></p>
 */
public interface PropertyReaderInterface extends QtObjectInterface
{
    /**
     * @hidden
     * <p>Implementor class for interface {@link io.qt.qt3d.render.PropertyReaderInterface}</p>
     */
    public static abstract class Impl extends QtObject
        implements io.qt.qt3d.render.PropertyReaderInterface
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @NativeAccess
        private static final class ConcreteWrapper extends PropertyReaderInterface.Impl {
            
            @NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @QtUninvokable
            public java.lang.Object readProperty(java.lang.Object v){
                return readProperty_native_cref_QVariant(QtJambi_LibraryUtilities.internal.nativeId(this), v);
            }
            private native static java.lang.Object readProperty_native_cref_QVariant(long __this__nativeId, java.lang.Object v);
            
        }
        
        
        /**
         * <p>See <code>Qt3DRender::PropertyReaderInterface::<wbr>PropertyReaderInterface()</code></p>
         */
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(PropertyReaderInterface instance);
        
        /**
         * <p>See <code>Qt3DRender::PropertyReaderInterface::<wbr>readProperty(QVariant)</code></p>
         */
        @QtUninvokable
        public abstract java.lang.Object readProperty(java.lang.Object v);
        
        private native static java.lang.Object readProperty_native_cref_QVariant(long __this__nativeId, java.lang.Object v);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         * @hidden
         */
        @NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <code>Qt3DRender::PropertyReaderInterface::<wbr>readProperty(QVariant)</code></p>
     */
    @QtUninvokable
    public java.lang.Object readProperty(java.lang.Object v);
    
}

==> qtjambi-qt3drender-6.7.0-sources.jar: io/qt/qt3d/render/PropertyReaderInterface.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>Qt3DRender::PropertyReaderInterface</code></p>
 */
public interface PropertyReaderInterface extends QtObjectInterface
{
    /**
     * @hidden
     * <p>Implementor class for interface {@link io.qt.qt3d.render.PropertyReaderInterface}</p>
     */
    public static abstract class Impl extends QtObject
        implements io.qt.qt3d.render.PropertyReaderInterface
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @NativeAccess
        private static final class ConcreteWrapper extends PropertyReaderInterface.Impl {
            
            @NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @QtUninvokable
            public java.lang.Object readProperty(java.lang.Object v){
                return readProperty_native_cref_QVariant(QtJambi_LibraryUtilities.internal.nativeId(this), v);
            }
            private native static java.lang.Object readProperty_native_cref_QVariant(long __this__nativeId, java.lang.Object v);
            
        }
        
        
        /**
         * <p>See <code>Qt3DRender::PropertyReaderInterface::<wbr/>PropertyReaderInterface()</code></p>
         */
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(PropertyReaderInterface instance);
        
        /**
         * <p>See <code>Qt3DRender::PropertyReaderInterface::<wbr/>readProperty(QVariant)</code></p>
         */
        @QtUninvokable
        public abstract java.lang.Object readProperty(java.lang.Object v);
        
        private native static java.lang.Object readProperty_native_cref_QVariant(long __this__nativeId, java.lang.Object v);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         * @hidden
         */
        @NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <code>Qt3DRender::PropertyReaderInterface::<wbr/>readProperty(QVariant)</code></p>
     */
    @QtUninvokable
    public java.lang.Object readProperty(java.lang.Object v);
    
}
